<?php
/**
 * Plugin Name.
 *
 * @package   Plugin_Name_Admin
 * @author    Anurag Singh <anurag722@hotmail.com>
 * @license   GPL-2.0+
 * @link      http://example.com
 * @copyright 2014 Your Name or Company Name
 */

/**
 * Plugin class. This class should ideally be used to work with the
 * administrative side of the WordPress site.
 *
 * If you're interested in introducing public-facing
 * functionality, then refer to `class-plugin-name.php`
 *
 * @TODO: Rename this class to a proper name for your plugin.
 *
 * @package Plugin_Name_Admin
 * @author  Anurag Singh <anurag722@hotmail.com>
 */
class Atf_Admin {

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Slug of the plugin screen.
	 *
	 * @since    1.0.0
	 *
	 * @var      string
	 */
	protected $plugin_screen_hook_suffix = null;

	/**
	 * Initialize the plugin by loading admin scripts & styles and adding a
	 * settings page and menu.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		/*
		 * @TODO :
		 *
		 * - Uncomment following lines if the admin class should only be available for super admins
		 */
		/* if( ! is_super_admin() ) {
			return;
		} */

		/*
		 * Call $plugin_slug from public plugin class.
		 *
		 * @TODO:
		 *
		 * - Rename "Plugin_Name" to the name of your initial plugin class
		 *
		 */
		$plugin = Atf::get_instance();
		$this->plugin_slug = $plugin->get_plugin_slug();

		// Load admin style sheet and JavaScript.
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_styles' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );

		// Add the options page and menu item.
		add_action( 'admin_menu', array( $this, 'add_plugin_admin_menu' ) );

		

		// Add an action link pointing to the options page.
		$plugin_basename = plugin_basename( plugin_dir_path( realpath( dirname( __FILE__ ) ) ) . $this->plugin_slug . '.php' );
		add_filter( 'plugin_action_links_' . $plugin_basename, array( $this, 'add_action_links' ) );

		/*
		 * Define custom functionality.
		 *
		 * Read more about actions and filters:
		 * http://codex.wordpress.org/Plugin_API#Hooks.2C_Actions_and_Filters
		 */
		add_action( '@TODO', array( $this, 'action_method_name' ) );
		add_action( 'wp_ajax_save_form', array( $this, 'action_save_form' ) );
		add_action( 'wp_ajax_update_form', array( $this, 'action_update_form' ) );
		add_action( 'wp_ajax_save_form_structure', array( $this, 'action_save_form_structure' ) );
		add_action( 'wp_ajax_update_form_structure', array( $this, 'action_update_form_structure' ) );
		add_action( 'wp_ajax_get_form_structure', array( $this, 'action_get_form_structure' ) );
		add_action( 'wp_ajax_send_mail', array( $this, 'action_send_mail' ) );
		add_action( 'wp_ajax_get_form', array( $this, 'action_get_form' ) );
		add_action( 'wp_ajax_get_final_form', array( $this, 'action_get_final_form' ) );
		add_action( 'wp_ajax_get_form_analytics', array( $this, 'action_get_form_analytics' ) );
		add_action( 'wp_ajax_save_autoresponder', array( $this, 'action_save_autoresponder' ) );
		add_action( 'wp_ajax_get_autoresponder', array( $this, 'action_get_autoresponder' ) );

		add_action( 'wp_ajax_save_autoresponder_schedule', array( $this, 'action_save_autoresponder_schedule' ) );
		add_action( 'wp_ajax_update_autoresponder_schedule', array( $this, 'action_update_autoresponder_schedule' ) );
		add_action( 'wp_ajax_get_autoresponder_schedule', array( $this, 'action_get_autoresponder_schedule' ) );
		add_action( 'wp_ajax_delete_autoresponder_schedule', array( $this, 'action_delete_autoresponder_schedule' ) );

		add_action( 'wp_ajax_parse_csv', array( $this, 'action_parse_csv' ) );
		add_action( 'wp_ajax_export_csv', array( $this, 'action_export_csv' ) );

		add_filter( '@TODO', array( $this, 'filter_method_name' ) );

	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		/*
		 * @TODO :
		 *
		 * - Uncomment following lines if the admin class should only be available for super admins
		 */
		/* if( ! is_super_admin() ) {
			return;
		} */

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Register and enqueue admin-specific style sheet.
	 *
	 * @TODO:
	 *
	 * - Rename "Plugin_Name" to the name your plugin
	 *
	 * @since     1.0.0
	 *
	 * @return    null    Return early if no settings page is registered.
	 */
	public function enqueue_admin_styles() {

		if ( ! isset( $this->plugin_screen_hook_suffix ) ) {
			return;
		}

		$screen = get_current_screen();
		if ( $this->plugin_screen_hook_suffix == $screen->id ) {
			wp_enqueue_style( $this->plugin_slug .'-admin-styles', plugins_url( 'assets/css/admin.css', __FILE__ ), array(), Atf::VERSION );
			wp_enqueue_style( $this->plugin_slug .'-dropzone-styles', plugins_url( 'assets/css/dropzone.css', __FILE__ ), array(), Atf::VERSION );
			wp_enqueue_style( $this->plugin_slug .'-zebra_datepicker-styles', plugins_url( 'assets/css/zebra_datepicker.css', __FILE__ ), array(), Atf::VERSION );
		}

		if ( $screen->id == 'air-tight-form_page_atf_leads') {
			wp_enqueue_style( $this->plugin_slug .'-admin-styles', plugins_url( 'assets/css/admin.css', __FILE__ ), array(), Atf::VERSION );
			wp_enqueue_style( $this->plugin_slug .'-leads-styles', plugins_url( 'assets/css/leads.css', __FILE__ ), array(), Atf::VERSION );
			wp_enqueue_style( $this->plugin_slug .'-chosen-styles', plugins_url( 'assets/css/chosen.css', __FILE__ ), array(), Atf::VERSION );
			wp_enqueue_style( $this->plugin_slug .'-dropzone-styles', plugins_url( 'assets/css/dropzone.css', __FILE__ ), array(), Atf::VERSION );
		}


		if ( $screen->id == 'air-tight-form_page_atf_reports') {
			wp_enqueue_style( $this->plugin_slug .'-admin-styles', plugins_url( 'assets/css/admin.css', __FILE__ ), array(), Atf::VERSION );
			wp_enqueue_style( $this->plugin_slug .'-reports-styles', plugins_url( 'assets/css/reports.css', __FILE__ ), array(), Atf::VERSION );
		}

		if ( $screen->id == 'air-tight-form_page_atf_settings') {
			wp_enqueue_style( $this->plugin_slug .'-admin-styles', plugins_url( 'assets/css/admin.css', __FILE__ ), array(), Atf::VERSION );
			wp_enqueue_style( $this->plugin_slug .'-settings-styles', plugins_url( 'assets/css/settings.css', __FILE__ ), array(), Atf::VERSION );
		}

		if ( $screen->id == 'air-tight-form_page_atf_autoresponders') {
			wp_enqueue_style( $this->plugin_slug .'-admin-styles', plugins_url( 'assets/css/admin.css', __FILE__ ), array(), Atf::VERSION );
			wp_enqueue_style( $this->plugin_slug .'-autoresponders-styles', plugins_url( 'assets/css/autoresponders.css', __FILE__ ), array(), Atf::VERSION );
		}
	}

	/**
	 * Register and enqueue admin-specific JavaScript.
	 *
	 * @TODO:
	 *
	 * - Rename "Plugin_Name" to the name your plugin
	 *
	 * @since     1.0.0
	 *
	 * @return    null    Return early if no settings page is registered.
	 */
	public function enqueue_admin_scripts() {

		if ( ! isset( $this->plugin_screen_hook_suffix ) ) {
			return;
		}

		$screen = get_current_screen();
		if ( $this->plugin_screen_hook_suffix == $screen->id ) {
			wp_enqueue_script( $this->plugin_slug . '-admin-script-modernizr', plugins_url( 'assets/js/modernizr.custom.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script-classie', plugins_url( 'assets/js/classie.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script-progressButton', plugins_url( 'assets/js/progressButton.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script-dropzone', plugins_url( 'assets/js/dropzone.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script-jquerytinycolorpicker', plugins_url( 'assets/js/jquery.tinycolorpicker.min.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script-datepicker', plugins_url( 'assets/js/zebra_datepicker.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script', plugins_url( 'assets/js/admin.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
		}

		if ( $screen->id == 'air-tight-form_page_atf_leads') {
			wp_enqueue_script( $this->plugin_slug . '-admin-script-modernizr', plugins_url( 'assets/js/modernizr.custom.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script-classie', plugins_url( 'assets/js/classie.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script-progressButton', plugins_url( 'assets/js/progressButton.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-leads-script', plugins_url( 'assets/js/leads.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-chosen-script', plugins_url( 'assets/js/chosen.jquery.min.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script-dropzone', plugins_url( 'assets/js/dropzone.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
		}

		if ( $screen->id == 'air-tight-form_page_atf_reports') {
			wp_enqueue_script( $this->plugin_slug . '-reports-chart', plugins_url( 'assets/js/Chart.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-reports-jquery-ui', plugins_url( 'assets/js/jquery-ui.min.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-reports-script', plugins_url( 'assets/js/reports.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
		}

		if ( $screen->id == 'air-tight-form_page_atf_settings') {
			wp_enqueue_script( $this->plugin_slug . '-serialize_json-script', plugins_url( 'assets/js/jquery_serializeJSON.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-settings-script', plugins_url( 'assets/js/settings.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
		}

		if ( $screen->id == 'air-tight-form_page_atf_autoresponders') {
			wp_enqueue_script( $this->plugin_slug . '-serialize_json-script', plugins_url( 'assets/js/jquery_serializeJSON.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-autoresponders-script', plugins_url( 'assets/js/autoresponders.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
		}
	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */
	public function add_plugin_admin_menu() {

		/*
		 * Add a settings page for this plugin to the Settings menu.
		 *
		 * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
		 *
		 *        Administration Menus: http://codex.wordpress.org/Administration_Menus
		 *
		 * @TODO:
		 *
		 * - Change 'Page Title' to the title of your plugin admin page
		 * - Change 'Menu Text' to the text for menu item for the plugin settings page
		 * - Change 'manage_options' to the capability you see fit
		 *   For reference: http://codex.wordpress.org/Roles_and_Capabilities
		 */
		$this->plugin_screen_hook_suffix = add_menu_page(
			__( 'Air Tight Form', $this->plugin_slug ),
			__( 'Air Tight Form', $this->plugin_slug ),
			'edit_others_posts',
			$this->plugin_slug,
			array( $this, 'display_plugin_admin_page' ),
			'',
			11
			);

		add_submenu_page(
			$this->plugin_slug,
			'Leads', 
			'Leads',
			'edit_others_posts',
			$this->plugin_slug.'_leads',
			array($this, 'display_plugin_admin_leads_page')
			);

		add_submenu_page(
			$this->plugin_slug,
			'Reports', 
			'Reports',
			'edit_others_posts',
			$this->plugin_slug.'_reports',
			array($this, 'display_plugin_admin_reports_page')
			);

		add_submenu_page(
			$this->plugin_slug,
			'Autoresponders', 
			'Autoresponders',
			'edit_others_posts',
			$this->plugin_slug.'_autoresponders',
			array($this, 'display_plugin_admin_autoresponders_page')
			);

		// add_submenu_page(
		// 	$this->plugin_slug,
		// 	'Settings', 
		// 	'Settings',
		// 	'edit_others_posts',
		// 	$this->plugin_slug.'_settings',
		// 	array($this, 'display_plugin_admin_settings_page')
		// 	);
	} 

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function display_plugin_admin_page() {
		include_once( 'views/admin.php' );
	}

	public function display_plugin_admin_leads_page() {
		include_once( 'views/leads.php' );
	}

	public function display_plugin_admin_reports_page() {
		include_once( 'views/reports.php' );
	}

	public function display_plugin_admin_autoresponders_page() {
		include_once( 'views/autoresponders.php' );
	}

	public function display_plugin_admin_settings_page() {
		include_once( 'views/settings.php' );
	}
	/**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.0.0
	 */
	public function add_action_links( $links ) {

		return array_merge(
			array(
				'settings' => '<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_slug ) . '">' . __( 'Settings', $this->plugin_slug ) . '</a>'
				),
			$links
			);

	}

	/**
	 * NOTE:     Actions are points in the execution of a page or process
	 *           lifecycle that WordPress fires.
	 *
	 *           Actions:    http://codex.wordpress.org/Plugin_API#Actions
	 *           Reference:  http://codex.wordpress.org/Plugin_API/Action_Reference
	 *
	 * @since    1.0.0
	 */
	public function action_method_name() {
		// @TODO: Define your action hook callback here
	}


	// EXPORT CSV
	public function action_export_csv() {
		// @TODO: Define your action hook callback here
		$filename = "contacts.csv";
		header('Content-Type: text/csv; charset=utf-8');
		header('Content-Disposition: attachment; filename='.$filename);
		
		global $wpdb;

		$table_name1 = $wpdb->prefix . "atf_csv_imports"; 
		$table_name2 = $wpdb->prefix . "atf_leads"; 
		$output = "";
		$query = "SELECT name, email_address, contact_number, address, website, dob FROM $table_name1 UNION SELECT name, email_address, contact_number, address, website, dob FROM $table_name2";

		$results = $wpdb->get_results($query);
		// var_dump($results);

		foreach ( $results as $result ) 
		{
			$output = $output
			.$result->name.","
			.$result->email_address.","
			.$result->contact_number.","
			.$result->address.","
			.$result->website.","
			.$result->dob
			."\n";
		}

		// $output_handle = fopen('php://output', 'w');
		// fputs($output_handle, $output);
		
		// header('Content-Type:application/force-download');
		echo $output;
		exit;

	}
	// GET FILESIZE
	function curl_get_file_size( $url ) {
  // Assume failure.
		$result = -1;

		$curl = curl_init( $url );

  // Issue a HEAD request and follow any redirects.
		curl_setopt( $curl, CURLOPT_NOBODY, true );
		curl_setopt( $curl, CURLOPT_HEADER, true );
		curl_setopt( $curl, CURLOPT_RETURNTRANSFER, true );
		curl_setopt( $curl, CURLOPT_FOLLOWLOCATION, true );

		$data = curl_exec( $curl );
		curl_close( $curl );

		if( $data ) {
			$content_length = "unknown";
			$status = "unknown";

			if( preg_match( "/^HTTP\/1\.[01] (\d\d\d)/", $data, $matches ) ) {
				$status = (int)$matches[1];
			}

			if( preg_match( "/Content-Length: (\d+)/", $data, $matches ) ) {
				$content_length = (int)$matches[1];
			}

			if( $status == 200 || ($status > 300 && $status <= 308) ) {
				$result = $content_length;
			}
		}

		return $result;
	}

	// PARSE CSV HERE
	public function action_parse_csv() {
		// @TODO: Define your action hook callback here
		global $wpdb;
		$url = $_POST['url'];
		// echo $url;
		
		$length = $this->curl_get_file_size($url);
		// echo $length;
		
		$handler = fopen($_POST['url'], "r");
		
		$table_name = $wpdb->prefix . "atf_csv_imports"; 

		// PARSING CSV 
		// FORMAT: NAME, EMAIL, CONTACT, ADDRESS, WEBSITE, DOB
        //loop through the csv file and insert into database 
		$contact_ctr = 0;

		while (($data = fgetcsv($handler,$length,",","'"))!== FALSE){
			$name = $data[0];
			$email = $data[1];
			$contact = $data[2];
			$address = $data[3];
			$website = $data[4];
			$dob = $data[5];

			$result = $wpdb->insert($table_name,
				array(
					'name'=>$name,
					'email_address'=>$email,
					'contact_number'=>$contact,
					'address'=>$address,
					'website'=>$website,
					'dob'=>$dob
					)
				);
			$contact_ctr++;
		}

		echo "$contact_ctr contacts imported.";
	}

	public function action_save_autoresponder_schedule() {
		// @TODO: Define your action hook callback here

		global $wpdb;
		$table_name = $wpdb->prefix . "atf_customized_forms"; 
		$form_name = $wpdb->get_var("SELECT form_name FROM $table_name WHERE id = '".$_POST['form_id']."'");
		echo $form_name;

		$table_name = $wpdb->prefix . "atf_autoresponder_scheduler"; 

		$response = $wpdb->insert($table_name,
			array('form_id' => $_POST['form_id'],
				'form_name' => $form_name,
				'autoresponder_name' => $_POST['autoresponder_name'],
				'autoresponder_body' => $_POST['autoresponder_body'],
				'schedule_delay' => $_POST['schedule_delay']
				)
			);

	}

	public function action_update_autoresponder_schedule() {
		// @TODO: Define your action hook callback here

		global $wpdb;
		$table_name = $wpdb->prefix . "atf_customized_forms"; 
		$form_name = $wpdb->get_var("SELECT form_name FROM $table_name WHERE id = '".$_POST['form_id']."'");
		echo $form_name;

		$table_name = $wpdb->prefix . "atf_autoresponder_scheduler"; 

		$response = $wpdb->update($table_name,
			array('form_id' => $_POST['form_id'],
				'form_name' => $form_name,
				'autoresponder_name' => $_POST['autoresponder_name'],
				'autoresponder_body' => $_POST['autoresponder_body'],
				'schedule_delay' => $_POST['schedule_delay']
				),
			array('id' => $_POST['id'])
			);

	}


	public function action_delete_autoresponder_schedule() {
		// @TODO: Define your action hook callback here

		global $wpdb;
		$table_name = $wpdb->prefix . "atf_autoresponder_scheduler"; 

		$id = $_POST['id'];
		$msg = $wpdb->delete($table_name,
			array('id'=>$id));
		echo $msg;
	}


	public function action_get_autoresponder_schedule() {
		// @TODO: Define your action hook callback here

		global $wpdb;
		$table_name = $wpdb->prefix . "atf_autoresponder_scheduler"; 
		$id = $_POST['id'];
		$result = $wpdb->get_var("SELECT autoresponder_body FROM $table_name WHERE id = $id");
		$result = stripslashes($result);
		echo $result;

	}


		public function action_save_autoresponder() {
		// @TODO: Define your action hook callback here
			global $wpdb;

			$form_id = $_POST['form_id'];
			$content = $_POST['content'];
			$table_name = $wpdb->prefix . "atf_form_autoresponder"; 
			$result = $wpdb->query("SELECT * FROM $table_name WHERE form_id = '".$form_id."'");
			if($result>0){
				$response = $wpdb->update( $table_name, 
					array( 'form_id' => $form_id, 
						'form_autoresponder' => $content),
					array( 'form_id' => $form_id ) );

				echo "updated";
			}

			else{
				$response = $wpdb->insert( $table_name, 
					array( 'form_id' => $form_id, 
						'form_autoresponder' => $content)
					);
				echo "inserted";
			}

		}

		public function action_get_autoresponder() {
		// @TODO: Define your action hook callback here
			global $wpdb;
			$form_id = $_POST['form_id'];
			$content = "";
			$table_name = $wpdb->prefix . "atf_form_autoresponder"; ;
			
			$result = $wpdb->get_var("SELECT form_autoresponder FROM $table_name WHERE form_id = $form_id");
			$result = stripslashes($result);
			echo $result;
		}


		public function action_get_final_form() {
		// @TODO: Define your action hook callback here
			$id = $_POST['form_id'];

			global $wpdb;

			$form_name = "";
			$header_bg_color = "";
			$header_text = "";
			$header_background_image = "";
			$body_desc = "";
			$body_redirect = "";
			$has_footer = "";
			$footer_heading = "";
			$footer_subheading = "";
			$footer_address = "";
			$footer_contact = "";
			$footer_email = "";



			$table_name = $wpdb->prefix . "atf_customized_forms"; 
			$query = "SELECT * FROM ".$table_name." WHERE id = ".$id;


			$results = $wpdb->get_row($query);
			if($results != NULL){
				$form_name = $results->form_name;
				$header_bg_color = $results->header_bg_color;
				$header_text = $results->header_text;
				$header_background_image = $results->header_background_image;
				$body_desc = $results->body_desc;
				$body_redirect = $results->body_redirect;
				$has_footer = $results->has_footer;
				$footer_heading = $results->footer_heading;
				$footer_subheading = $results->footer_subheading;
				$footer_address = $results->footer_address;
				$footer_contact = $results->footer_contact;
				$footer_email = $results->footer_email;
			}

			$table_name = $wpdb->prefix . "atf_form_structure"; 
			$query = "SELECT * FROM ".$table_name." WHERE form_id = ".$id;

			$results = $wpdb->get_row($query);
			if($results != NULL){
				$has_name = $results->has_name;
				$has_email = $results->has_email;
				$has_contact = $results->has_contact;
				$has_dob = $results->has_dob;
				$has_website = $results->has_website;
				$has_address = $results->has_address;
				$has_message = $results->has_message;
			}


			if($id < 21) { ?>
			<link rel="stylesheet" type="text/css" href="<?php echo home_url( "wp-content/plugins/atf/assets/default_stylesheets/default_form_$id.css", __FILE__ ); ?>">
			<?php } ?>
			<?php

			if(($header_background_image!="")||($header_text!="")){
				echo "<div class=\"resultant-form-header\" style=\"min-height: 200px; text-align: center; background-color: $header_bg_color; ";
				if($header_background_image) echo "background: url('".$header_background_image."'); background-size: 100%; \">\n"; 
				else echo "\">\n";
				echo "						<span class=\"resultant-banner-header-text\" style=\"font-size: 24px; background: none; border: none; outline: none; padding: 10px 10px; color: #fff; line-height: 200px;  min-height: 200px; display:block; background-color: rgba(0,0,0,0.2); text-align: center;\">$header_text</span>\n"; 
				echo "					</div>\n"; 
			}
			echo "					<div class=\"resultant-form-body\" style=\"padding: 20px 20px; background: #fff; text-align: center; min-height: 100px;\">\n"; 
			echo "						<span class=\"resultant-form-desc\" style=\"font-size: 24px; font-family: 'lato', sans-serif; text-align: center; color: #888; padding: 5px;\">$body_desc</span>\n"; 
			echo "\n"; 
			echo "						<div class=\"row main-form resultant-main-form\" style=\"padding: 15px 0px;\">\n"; 
			echo "							<form class=\"atf-form\" data-fid=\"$id\" action=\"action.php\" method=\"post\" onsubmit=\"return false;\">\n"; 
			echo "								<div class=\"row\">\n"; 
			echo "									<input type=\"hidden\" id=\"main_form_name\" value=\"$form_name\" name=\"main_form_name\" >\n"; 
			echo "									<input type=\"hidden\" id=\"main_form_id\" value=\"$id\" name=\"main_form_id\" >\n"; 

			if($has_name=="1")
				echo "									<input class=\"main-form-input\" placeholder=\"Name\" type=\"text\" id=\"main_form_name\" name=\"Name\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

			if($has_email=="1")
				echo "									<input class=\"main-form-input\" placeholder=\"Email\" type=\"email\" id=\"main_form_email\" name=\"Email\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

			if($has_contact=="1")
				echo "									<input class=\"main-form-input\" placeholder=\"Contact\" type=\"tel\" id=\"main_form_contact\" name=\"Contact\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

			if($has_dob=="1")
				echo "									<input class=\"main-form-input\" placeholder=\"dob\" type=\"text\" id=\"main_form_dob\" name=\"DOB\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

			if($has_website=="1")
				echo "									<input class=\"main-form-input\" placeholder=\"website\" type=\"text\" id=\"main_form_website\" name=\"Website\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

			echo "									<input class=\"main-form-id\" type=\"hidden\" id=\"main_form_id\" value=\"$id\">\n"; 

			echo "\n"; 			

			if($has_address=="1")
				echo "									<textarea class=\"main-form-input\" placeholder=\"Address\" id=\"main_form_address\" name=\"Address\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\"></textarea>\n"; 

			if($has_message=="1")
				echo "									<textarea class=\"main-form-input\" placeholder=\"Message\" id=\"main_form_message\" name=\"Message\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\"></textarea>\n"; 
			echo "									<p class=\"perspective\">\n"; 
			echo "										<button type=\"submit\" id=\"main_form_submit\" class=\"main_form_submit btn btn-8 btn-8g\">\n"; 
			echo "											<i class=\"fa fa-envelope\"></i>SUBMIT\n"; 
			echo "										</button>\n"; 
			echo "									</p>\n"; 
			echo "								</div>\n"; 
			echo "							</form>\n"; 
			echo "						</div>\n"; 
			echo "					</div>\n"; 
			if($has_footer == "1"){
				echo "					<div class=\"resultant-form-footer\" style=\"padding: 20px 20px; background: #98D6D3; min-height: 100px; text-align: center;\">\n"; 
				echo "						<div class=\"resultant-footer-head\" style=\"font-size: 24px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 5px; margin-bottom: 10px; display: inline-block;\">$footer_heading</div>\n"; 
				echo "						<div class=\"resultant-footer-subhead\" style=\"font-size: 14px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 5px; padding-bottom: 20px; border-bottom: 1px solid #BEE6FF;\">$footer_subheading</div>\n"; 
				if($footer_address!=""){
					echo "						<div class=\"resultant-foo-address\" style=\"font-size: 14px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 10px; margin-bottom: 10px; display: block;\">\n"; 
					echo "							<i class=\"fa fa-map-marker\"></i>\n"; 
					echo "							<span class=\"resultant-address\">$footer_address</span>\n"; 
					echo "						</div>\n"; 
				}
				if($footer_contact!=""){
					echo "						<span class=\"resultant-foo-contact\" style=\"font-size: 14px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 10px; margin-bottom: 10px; display: inline-block;\">\n"; 
					echo "							<i class=\"fa fa-phone\"></i>\n"; 
					echo "							<span class=\"resultant-contact\">$footer_contact</span>\n"; 
					echo "						</span>\n"; 
				}
				if($footer_email!=""){
					echo "						<span class=\"resultant-foo-email\" style=\"font-size: 14px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 10px; margin-bottom: 10px; display: inline-block;\">\n"; 
					echo "							<i class=\"fa fa-envelope\"></i>\n"; 
					echo "							<span class=\"resultant-email\">$footer_email</span>\n"; 
					echo "						</span>\n"; 
					echo "					</div>\n"; 
				}
			}
			echo "				\n";

		// GET FINAL FORM ENDS HERE
		}

	// GET FORM STRUCTURE
		public function action_get_form_structure() {
		// @TODO: Define your action hook callback here
			global $wpdb;

			$form_id = "";

			$form_id = $_POST['form_id'];

			$table_name = $wpdb->prefix."atf_form_structure";
			$form_data = $wpdb->get_row("SELECT * FROM $table_name WHERE form_id = $form_id");

			$form_data = json_encode($form_data);
			echo $form_data;
		}


	// save form structure
		public function action_save_form_structure() {
		// @TODO: Define your action hook callback here
			global $wpdb;

			$form_id = "";
			$has_name = "";
			$has_email = "";
			$has_contact = "";
			$has_dob = "";
			$has_website = "";
			$has_address = "";
			$has_message = "";

			$form_id = $_POST["form_id"];
			$has_name = $_POST["has_name"];
			$has_email = $_POST["has_email"];
			$has_contact = $_POST["has_contact"];
			$has_dob = $_POST["has_dob"];
			$has_website = $_POST["has_website"];
			$has_address = $_POST["has_address"];
			$has_message = $_POST["has_message"];

			$table_name = $wpdb->prefix . "atf_form_structure"; 

			$query = $wpdb->insert( $table_name, 
				array( 'form_id' => $form_id, 
					'has_name' => $has_name,
					'has_email' => $has_email, 
					'has_contact' => $has_contact,
					'has_dob' => $has_dob,  
					'has_website' => $has_website, 
					'has_address' => $has_address,
					'has_message' => $has_message ) );

		}

	// save form structure
		public function action_update_form_structure() {
		// @TODO: Define your action hook callback here
			global $wpdb;

			$form_id = "";
			$has_name = "";
			$has_email = "";
			$has_contact = "";
			$has_dob = "";
			$has_website = "";
			$has_address = "";
			$has_message = "";

			$form_id = $_POST["form_id"];
			$has_name = $_POST["has_name"];
			$has_email = $_POST["has_email"];
			$has_contact = $_POST["has_contact"];
			$has_dob = $_POST["has_dob"];
			$has_website = $_POST["has_website"];
			$has_address = $_POST["has_address"];
			$has_message = $_POST["has_message"];

			$table_name = $wpdb->prefix . "atf_form_structure"; 

			$query = $wpdb->update( $table_name, 
				array( 'form_id' => $form_id, 
					'has_name' => $has_name,
					'has_email' => $has_email, 
					'has_contact' => $has_contact,
					'has_dob' => $has_dob,  
					'has_website' => $has_website, 
					'has_address' => $has_address,
					'has_message' => $has_message ),
				array( 'form_id' => $form_id ) );

		}


	// get form analytics
		public function action_get_form_analytics() {
		// @TODO: Define your action hook callback here
			global $wpdb;
			$table_name = $wpdb->prefix."atf_form_analytics";
			$analytics = $wpdb->get_row("SELECT SUM(form_views) as total_views, SUM(form_submissions) as total_submissions FROM $table_name");

			$form_stats = $wpdb->get_results("SELECT * FROM $table_name");
			$data = array();
			$data['analytics'] = $analytics;
			$data['form_stats'] = $form_stats;

			echo json_encode($data);
		}


		public function action_get_form() {
		// Get the form variables for the selected form
			global $wpdb;
			$form_id = "";

			$form_id = $_POST['form_id'];

			$table_name = $wpdb->prefix."atf_customized_forms";
			$form_data = $wpdb->get_row("SELECT * FROM $table_name WHERE id = $form_id");

			$form_data = json_encode($form_data);
			echo $form_data;

		}

	// Saving resultant form that's created in wp-admin
		public function action_save_form() {
			global $wpdb;
			$form_name = "";
			$form_header_bg_color = "";
			$form_header_text = "";
			$form_background_image = "";
			$form_body_desc = "";
			$form_body_redirect = "";
			$has_footer = "";
			$form_footer_heading = "";
			$form_footer_subheading = "";
			$form_footer_address = "";
			$form_footer_contact = "";
			$form_footer_email = "";

			if (isset($_POST['form_name'])||$_POST['form_name']!='undefined') {
				$form_name = $_POST['form_name'];
			}

			if (isset($_POST['form_header_bg_color'])||$_POST['form_header_bg_color']!='undefined') {
				$form_header_bg_color = $_POST['form_header_bg_color'];
			}

			if (isset($_POST['form_header_text'])||$_POST['form_header_text']!='undefined') {
				$form_header_text = $_POST['form_header_text'];
			}

			if (isset($_POST['form_background_image'])||$_POST['form_background_image']!='undefined') {
				$form_background_image = $_POST['form_background_image'];
			}

			if (isset($_POST['form_body_desc'])||$_POST['form_body_desc']!='undefined') {
				$form_body_desc = $_POST['form_body_desc'];
			}

			if (isset($_POST['form_body_redirect'])||$_POST['form_body_redirect']!='undefined') {
				$form_body_redirect = $_POST['form_body_redirect'];
			}

			if (isset($_POST['has_footer'])||$_POST['has_footer']!='undefined') {
				$has_footer = $_POST['has_footer'];
			}

			if (isset($_POST['form_footer_heading'])||$_POST['form_footer_heading']!='undefined') {
				$form_footer_heading = $_POST['form_footer_heading'];
			}

			if (isset($_POST['form_footer_subheading'])||$_POST['form_footer_subheading']!='undefined') {
				$form_footer_subheading = $_POST['form_footer_subheading'];
			}

			if (isset($_POST['form_footer_address'])||$_POST['form_footer_address']!='undefined') {
				$form_footer_address = $_POST['form_footer_address'];
			}


			if (isset($_POST['form_footer_contact'])||$_POST['form_footer_contact']!='undefined') {
				$form_footer_contact = $_POST['form_footer_contact'];
			}

			if (isset($_POST['form_footer_email'])||$_POST['form_footer_email']!='undefined') {
				$form_footer_email = $_POST['form_footer_email'];
			}


		 	// status variable values: NULL, transfered
			$table_name = $wpdb->prefix . "atf_customized_forms"; 

			$query = $wpdb->insert( $table_name, 
				array( 'form_name' => $form_name, 
					'header_bg_color' => $form_header_bg_color,
					'header_text' => $form_header_text, 
					'header_background_image' => $form_background_image,
					'body_desc' => $form_body_desc,  
					'body_redirect' => $form_body_redirect, 
					'has_footer' => $has_footer,
					'footer_heading' => $form_footer_heading,
					'footer_subheading' => $form_footer_subheading,
					'footer_address' => $form_footer_address,
					'footer_contact' => $form_footer_contact,
					'footer_email' => $form_footer_email ) );

			$lastid = $wpdb->insert_id;
			echo $lastid;

			$table_name = $wpdb->prefix."atf_form_analytics";
			$query = $wpdb->insert($table_name,
				array('form_name' => $form_name,
					'form_id' => $lastid,
					'form_views' => 0,
					'form_submissions' => 0
					));
		}

	// Saving resultant form that's created in wp-admin
		public function action_update_form() {
			global $wpdb;
			$form_name = "";
			$form_header_bg_color = "";
			$form_header_text = "";
			$form_background_image = "";
			$form_body_desc = "";
			$form_body_redirect = "";
			$has_footer = "";
			$form_footer_heading = "";
			$form_footer_subheading = "";
			$form_footer_address = "";
			$form_footer_contact = "";
			$form_footer_email = "";


			$form_name = $_POST['form_name'];
			$form_id = $_POST['form_id'];
			$form_header_bg_color = $_POST['form_header_bg_color'];
			$form_header_text = $_POST['form_header_text'];
			$form_background_image = $_POST['form_background_image'];
			$form_body_desc = $_POST['form_body_desc'];
			$form_body_redirect = $_POST['form_body_redirect'];
			$has_footer = $_POST['has_footer'];
			$form_footer_heading = $_POST['form_footer_heading'];
			$form_footer_subheading = $_POST['form_footer_subheading'];
			$form_footer_address = $_POST['form_footer_address'];
			$form_footer_contact = $_POST['form_footer_contact'];
			$form_footer_email = $_POST['form_footer_email'];

		 	// status variable values: NULL, transfered
			$table_name = $wpdb->prefix . "atf_customized_forms"; 

			$query = $wpdb->update( $table_name, 
				array( 'form_name' => $form_name, 
					'header_bg_color' => $form_header_bg_color,
					'header_text' => $form_header_text, 
					'header_background_image' => $form_background_image,
					'body_desc' => $form_body_desc,  
					'body_redirect' => $form_body_redirect, 
					'has_footer' => $has_footer,
					'footer_heading' => $form_footer_heading,
					'footer_subheading' => $form_footer_subheading,
					'footer_address' => $form_footer_address,
					'footer_contact' => $form_footer_contact,
					'footer_email' => $form_footer_email ),
				array( 'id' => $form_id ) );

			$lastid = $form_id;
			echo $lastid;


			$table_name = $wpdb->prefix."atf_form_analytics";
			$query = $wpdb->update($table_name,
				array('form_name' => $form_name,
					'form_views' => 0,
					'form_submissions' => 0),
				array('form_id' => $form_id)
				);

		}


		public function action_send_mail(){
			$admin_email = get_option( 'admin_email' ); 
			$author = get_the_author();
			$headers = "MIME-Version: 1.0" . "\r\n";
			$headers .= "Content-type:text/html;charset=iso-8859-1" . "\r\n";
			// $headers .= "From: $author <$admin_email>"."\r\n";
			$message = "";
			$subject = "";
			$recipient_list = "";

			global $mail;
			$message = $_POST['message'];
			$subject = $_POST['subject'];
			$recipient_list = $_POST['recipient_list'];
			$contact_list = $_POST['contact_list'];
			wp_mail( $recipient_list, $subject, $message, $headers );
			wp_mail( $contact_list, $subject, $message, $headers );
		}

	/**
	 * NOTE:     Filters are points of execution in which WordPress modifies data
	 *           before saving it or sending it to the browser.
	 *
	 *           Filters: http://codex.wordpress.org/Plugin_API#Filters
	 *           Reference:  http://codex.wordpress.org/Plugin_API/Filter_Reference
	 *
	 * @since    1.0.0
	 */
	public function filter_method_name() {
		// @TODO: Define your filter hook callback here
	}
	public function set_html_content_type() {

		return 'text/html';
	}

}
