<?php
/**
 * Plugin Name.
 *
 * @package   ATF
 * @author    Your Name <anurag722@hotmail.com>
 * @license   GPL-2.0+
 * @link      http://example.com
 * @copyright 2014 Your Name or Company Name
 */

/**
 * Plugin class. This class should ideally be used to work with the
 * public-facing side of the WordPress site.
 *
 * If you're interested in introducing administrative or dashboard
 * functionality, then refer to `class-plugin-name-admin.php`
 *
 * @TODO: Rename this class to a proper name for your plugin.
 *
 * @package ATF
 * @author  Anurag Singh <anurag722@hotmail.com>
 */
class Atf {

	/**
	 * Plugin version, used for cache-busting of style and script file references.
	 *
	 * @since   1.0.0
	 *
	 * @var     string
	 */
	const VERSION = '1.0.0';

	/**
	 * @TODO - Rename "plugin-name" to the name of your plugin
	 *
	 * Unique identifier for your plugin.
	 *
	 *
	 * The variable name is used as the text domain when internationalizing strings
	 * of text. Its value should match the Text Domain file header in the main
	 * plugin file.
	 *
	 * @since    1.0.0
	 *
	 * @var      string
	 */
	protected $plugin_slug = 'atf';

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Initialize the plugin by setting localization and loading public scripts
	 * and styles.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		// Load plugin text domain
		add_action( 'init', array( $this, 'load_plugin_textdomain' ) );

		// Activate plugin when new blog is added
		add_action( 'wpmu_new_blog', array( $this, 'activate_new_site' ) );

		// Load public-facing style sheet and JavaScript.
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_styles' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

		/* Define custom functionality.
		 * Refer To http://codex.wordpress.org/Plugin_API#Hooks.2C_Actions_and_Filters
		 */
		add_action( '@TODO', array( $this, 'action_method_name' ) );
		add_filter( '@TODO', array( $this, 'filter_method_name' ) );


		// Updating Form Load Counter
		add_action( 'wp_ajax_update_view_ctr', array( $this, 'update_view_ctr' ) );
		add_action( 'wp_ajax_nopriv_update_view_ctr', array( $this, 'update_view_ctr' ) );

		
		// Updating Form Load Counter
		add_action( 'wp_ajax_update_submission_ctr', array( $this, 'update_submission_ctr' ) );
		add_action( 'wp_ajax_nopriv_update_submission_ctr', array( $this, 'update_submission_ctr' ) );

		// AutoResponder
		add_action( 'wp_ajax_autoresponder', array( $this, 'action_autoresponder' ) );
		add_action( 'wp_ajax_nopriv_autoresponder', array( $this, 'action_autoresponder' ) );

		// atf_view
		add_action( 'wp_ajax_atf_view_style', array( $this, 'atf_view_style' ) );
		add_action( 'wp_ajax_nopriv_atf_view_style', array( $this, 'atf_view_style' ) );

		// atf_view
		add_action( 'wp_ajax_atf_view', array( $this, 'action_atf_view' ) );
		add_action( 'wp_ajax_nopriv_atf_view', array( $this, 'action_atf_view' ) );

		// save lead 
		add_action( 'wp_ajax_save_lead', array( $this, 'action_save_lead' ) );
		add_action( 'wp_ajax_nopriv_save_lead', array( $this, 'action_save_lead' ) );
		
		// Adding ajax library in frontend
		add_action( 'wp_head', array( &$this, 'add_ajax_library' ) );

		// adding scheduler on form submission
		add_action( 'schedule_mail', array( &$this, 'action_schedule_mail' ) );

	}

	/**
	 * Return the plugin slug.
	 *
	 * @since    1.0.0
	 *
	 * @return    Plugin slug variable.
	 */
	public function get_plugin_slug() {
		return $this->plugin_slug;
	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Fired when the plugin is activated.
	 *
	 * @since    1.0.0
	 *
	 * @param    boolean    $network_wide    True if WPMU superadmin uses
	 *                                       "Network Activate" action, false if
	 *                                       WPMU is disabled or plugin is
	 *                                       activated on an individual blog.
	 */
	public static function activate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide  ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_activate();

					restore_current_blog();
				}

			} else {
				self::single_activate();
			}

		} else {
			self::single_activate();
		}

	}

	/**
	 * Fired when the plugin is deactivated.
	 *
	 * @since    1.0.0
	 *
	 * @param    boolean    $network_wide    True if WPMU superadmin uses
	 *                                       "Network Deactivate" action, false if
	 *                                       WPMU is disabled or plugin is
	 *                                       deactivated on an individual blog.
	 */
	public static function deactivate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_deactivate();

					restore_current_blog();

				}

			} else {
				self::single_deactivate();
			}

		} else {
			self::single_deactivate();
		}

	}

	/**
	 * Fired when a new site is activated with a WPMU environment.
	 *
	 * @since    1.0.0
	 *
	 * @param    int    $blog_id    ID of the new blog.
	 */
	public function activate_new_site( $blog_id ) {

		if ( 1 !== did_action( 'wpmu_new_blog' ) ) {
			return;
		}

		switch_to_blog( $blog_id );
		self::single_activate();
		restore_current_blog();

	}

	/**
	 * Get all blog ids of blogs in the current network that are:
	 * - not archived
	 * - not spam
	 * - not deleted
	 *
	 * @since    1.0.0
	 *
	 * @return   array|false    The blog ids, false if no matches.
	 */
	private static function get_blog_ids() {

		global $wpdb;

		// get an array of blog ids
		$sql = "SELECT blog_id FROM $wpdb->blogs
		WHERE archived = '0' AND spam = '0'
		AND deleted = '0'";

		return $wpdb->get_col( $sql );

	}

	/**
	 * Fired for each blog when the plugin is activated.
	 *
	 * @since    1.0.0
	 */
	private static function single_activate() {
		// @TODO: Define activation functionality here
		global $wpdb;
		// status variable values: NULL, transfered



		// Default forms
		$table_name = $wpdb->prefix . "atf_default_forms"; 
		$wpdb->query("DROP TABLE IF EXISTS $table_name");
		



		// Customized forms
		$table_name = $wpdb->prefix . "atf_customized_forms"; 
		$wpdb->query("DROP TABLE IF EXISTS $table_name");


		// Customized forms
		$table_name = $wpdb->prefix . "atf_form_analytics"; 
		$wpdb->query("DROP TABLE IF EXISTS $table_name");


		$table_name = $wpdb->prefix . "atf_autoresponder_scheduler"; 
		$wpdb->query("DROP TABLE IF EXISTS $table_name");

		// Leads
		$table_name = $wpdb->prefix . "atf_form_structure"; 
		$wpdb->query("DROP TABLE IF EXISTS $table_name");

		// CSV_IMPORTS
			// Leads
		$table_name = $wpdb->prefix . "atf_csv_imports"; 
		$wpdb->query("DROP TABLE IF EXISTS $table_name");


		// Default forms
		$table_name = $wpdb->prefix . "atf_default_forms"; 
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id INTEGER(9) NOT NULL AUTO_INCREMENT,
			form_name VARCHAR(255),
			header_bg_color VARCHAR(20),
			header_text VARCHAR(200),
			header_background_image VARCHAR(200),
			body_desc VARCHAR(200),
			body_redirect VARCHAR(200),
			has_footer VARCHAR(2),
			footer_heading VARCHAR(200),
			footer_subheading VARCHAR(200),
			footer_address VARCHAR(200),
			footer_contact VARCHAR(200),
			footer_email VARCHAR(200),
			UNIQUE KEY id (id)
			);";
require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
dbDelta( $sql );

			// Customized forms
$table_name = $wpdb->prefix . "atf_customized_forms"; 
$sql = "CREATE TABLE IF NOT EXISTS $table_name (
	id INTEGER(9) NOT NULL AUTO_INCREMENT,
	form_name VARCHAR(255),
	header_bg_color VARCHAR(20),
	header_text VARCHAR(200),
	header_background_image VARCHAR(200),
	body_desc VARCHAR(200),
	body_redirect VARCHAR(200),
	has_footer VARCHAR(2),
	footer_heading VARCHAR(200),
	footer_subheading VARCHAR(200),
	footer_address VARCHAR(200),
	footer_contact VARCHAR(200),
	footer_email VARCHAR(200),
	UNIQUE KEY id (id)
	);";
require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
dbDelta( $sql );


			// Customized forms
$table_name = $wpdb->prefix . "atf_form_analytics"; 
$sql = "CREATE TABLE IF NOT EXISTS $table_name (
	id INTEGER(9) NOT NULL AUTO_INCREMENT,
	form_id VARCHAR(20),
	form_name VARCHAR(255),
	form_views VARCHAR(20),
	form_submissions VARCHAR(20),
	UNIQUE KEY id (id)
	);";
require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
dbDelta( $sql );


// Customized forms
$table_name = $wpdb->prefix . "atf_form_autoresponder"; 
$sql = "CREATE TABLE IF NOT EXISTS $table_name (
	id INTEGER(9) NOT NULL AUTO_INCREMENT,
	form_id VARCHAR(20),
	form_autoresponder LONGTEXT,
	UNIQUE KEY id (id)
	);";
require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
dbDelta( $sql );

	// Customized forms
$table_name = $wpdb->prefix . "atf_autoresponder_scheduler"; 
$sql = "CREATE TABLE IF NOT EXISTS $table_name (
	id INTEGER(9) NOT NULL AUTO_INCREMENT,
	form_id VARCHAR(20),
	form_name VARCHAR(200),
	autoresponder_name VARCHAR(200),
	autoresponder_body LONGTEXT,
	schedule_delay INT(4),
	UNIQUE KEY id (id)
	);";

require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
dbDelta( $sql );


					// Leads
$table_name = $wpdb->prefix . "atf_leads"; 
$sql = "CREATE TABLE IF NOT EXISTS $table_name (
	id INTEGER(9) NOT NULL AUTO_INCREMENT,
	name VARCHAR(255),
	email_address VARCHAR(255),
	contact_number VARCHAR(255),
	dob VARCHAR(15),
	website VARCHAR(255),
	address VARCHAR(500),
	message VARCHAR(500),
	form_id VARCHAR(100),
	UNIQUE KEY id (id)
	);";

require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
dbDelta( $sql );


					// atf_form_structure
$table_name = $wpdb->prefix . "atf_form_structure"; 
$sql = "CREATE TABLE IF NOT EXISTS $table_name (
	id INTEGER(9) NOT NULL AUTO_INCREMENT,
	form_id VARCHAR(20),
	has_name VARCHAR(2),
	has_email VARCHAR(2),
	has_contact VARCHAR(2),
	has_dob VARCHAR(2),
	has_website VARCHAR(2),
	has_address VARCHAR(2),
	has_message VARCHAR(2),
	UNIQUE KEY id (id)
	);";

require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
dbDelta( $sql );

// CSV IMPORTS
$table_name = $wpdb->prefix . "atf_csv_imports"; 
$sql = "CREATE TABLE IF NOT EXISTS $table_name (
	id INTEGER(9) NOT NULL AUTO_INCREMENT,
	name VARCHAR(255),
	email_address VARCHAR(255),
	contact_number VARCHAR(255),
	address VARCHAR(500),
	website VARCHAR(255),
	dob VARCHAR(15),
	UNIQUE KEY id (id)
	);";

require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
dbDelta( $sql );

// install data into the database from the php array
// `inboundio_pro`.`wp_atf_customized_forms`
$wp_atf_customized_forms = array(
	array('form_name' => 'ATF','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Air Tight Form','header_background_image' => '','body_desc' => 'Subscription Form','body_redirect' => '','has_footer' => '1','footer_heading' => 'Air Tight Forms','footer_subheading' => 'Create, Customize, Deploy Forms','footer_address' => 'Bangalore, India','footer_contact' => '80023112332','footer_email' => 'admin@atf.com'),
	array('form_name' => 'blogger','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Blogger','header_background_image' => '','body_desc' => 'Feedback','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Subscribe','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Subscribe','header_background_image' => '','body_desc' => 'Register Your Email','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Glass UI','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Glass UI','header_background_image' => '','body_desc' => 'Provide your Details','body_redirect' => '','has_footer' => '1','footer_heading' => 'Global Health Care','footer_subheading' => 'Online health care services','footer_address' => 'Houston, Texas','footer_contact' => '+91 - 9004-080-007','footer_email' => 'sh@detective.com'),
	array('form_name' => 'Designer','header_bg_color' => 'rgb(3, 145, 206)','header_text' => '','header_background_image' => '','body_desc' => 'Registration Form','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Material','header_bg_color' => 'rgb(3, 145, 206)','header_text' => '','header_background_image' => '','body_desc' => 'Material Design','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Dark','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Web Architects','header_background_image' => '','body_desc' => 'Get Quote','body_redirect' => '','has_footer' => '1','footer_heading' => 'Web Architects','footer_subheading' => 'We Create We Innovate','footer_address' => 'Seattle, Washington','footer_contact' => '7723328121','footer_email' => 'admin@architect.com'),
	array('form_name' => 'Head Rotate','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Creative Header','header_background_image' => '','body_desc' => 'Register Here','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'contact us','header_bg_color' => 'rgb(3, 145, 206)','header_text' => '','header_background_image' => '','body_desc' => 'Contact Form','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'subscribe','header_bg_color' => 'rgb(3, 145, 206)','header_text' => '','header_background_image' => '','body_desc' => 'Subscribe','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Envelope','header_bg_color' => 'rgb(3, 145, 206)','header_text' => '','header_background_image' => '','body_desc' => 'Subscribe','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Save Form','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'LOGO','header_background_image' => '','body_desc' => 'Drop Us A Line','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'register','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'E Harbor','header_background_image' => '','body_desc' => 'E harbor Registration','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'delivery','header_bg_color' => 'rgb(3, 145, 206)','header_text' => '','header_background_image' => '','body_desc' => 'Delivery Details','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Form','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Car Pooling','header_background_image' => '','body_desc' => 'Contact Details','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Form','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Contact Form','header_background_image' => '','body_desc' => 'Please fill out your details here.','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Book','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Book My Seat','header_background_image' => '','body_desc' => 'Please fill out your details here.','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Club','header_bg_color' => 'rgba(0, 0, 0, 0)','header_text' => 'Dine Club','header_background_image' => '','body_desc' => 'Register Here','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Event','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'ATP Book Tickets','header_background_image' => '','body_desc' => 'Details','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => ''),
	array('form_name' => 'Launch','header_bg_color' => 'rgb(3, 145, 206)','header_text' => 'Product Launch','header_background_image' => '','body_desc' => 'Book Here','body_redirect' => '','has_footer' => '0','footer_heading' => '','footer_subheading' => '','footer_address' => '','footer_contact' => '','footer_email' => '')
	);

$table_name = $wpdb->prefix . "atf_customized_forms"; 
foreach ($wp_atf_customized_forms as $data) {
	$query = $wpdb->insert($table_name, $data);
}


// `inboundio_pro`.`wp_atf_form_analytics`
$wp_atf_form_analytics = array(
	array('form_id' => '1','form_name' => 'ATF','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '2','form_name' => 'blogger','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '3','form_name' => 'Subscribe','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '4','form_name' => 'Glass UI','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '5','form_name' => 'Designer','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '6','form_name' => 'Material','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '7','form_name' => 'Dark','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '8','form_name' => 'Head Rotate','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '9','form_name' => 'contact us','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '10','form_name' => 'subscribe','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '11','form_name' => 'Envelope','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '12','form_name' => 'Save Form','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '13','form_name' => 'register','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '14','form_name' => 'delivery','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '15','form_name' => 'Form','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '16','form_name' => 'Form','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '17','form_name' => 'Book','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '18','form_name' => 'Club','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '19','form_name' => 'Event','form_views' => '0','form_submissions' => '0'),
	array('form_id' => '20','form_name' => 'Launch','form_views' => '0','form_submissions' => '0')
	);


$table_name = $wpdb->prefix . "atf_form_analytics"; 
foreach ($wp_atf_form_analytics as $data) {
	$query = $wpdb->insert($table_name, $data);
}

$auto_responder = "";
$table_name = $wpdb->prefix . "atf_form_autoresponder"; 
foreach ($wp_atf_form_analytics as $data) {
	$query = $wpdb->insert($table_name,
		array('form_id'=> $data['form_id'],
			'form_autoresponder' => $auto_responder
			));
}

// `inboundio_pro`.`wp_atf_form_structure`
$wp_atf_form_structure = array(
	array('form_id' => '1','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '1','has_website' => '1','has_address' => '1','has_message' => '1'),
	array('form_id' => '2','has_name' => '1','has_email' => '1','has_contact' => '0','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '1'),
	array('form_id' => '3','has_name' => '1','has_email' => '1','has_contact' => '0','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '0'),
	array('form_id' => '4','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '1','has_website' => '0','has_address' => '1','has_message' => '1'),
	array('form_id' => '5','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '1','has_website' => '0','has_address' => '0','has_message' => '1'),
	array('form_id' => '6','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '0','has_website' => '1','has_address' => '1','has_message' => '0'),
	array('form_id' => '7','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '0','has_website' => '1','has_address' => '0','has_message' => '0'),
	array('form_id' => '8','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '1'),
	array('form_id' => '9','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '1'),
	array('form_id' => '10','has_name' => '0','has_email' => '1','has_contact' => '0','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '0'),
	array('form_id' => '11','has_name' => '0','has_email' => '1','has_contact' => '0','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '1'),
	array('form_id' => '12','has_name' => '1','has_email' => '1','has_contact' => '0','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '1'),
	array('form_id' => '13','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '1','has_website' => '0','has_address' => '0','has_message' => '0'),
	array('form_id' => '14','has_name' => '1','has_email' => '0','has_contact' => '1','has_dob' => '0','has_website' => '0','has_address' => '1','has_message' => '0'),
	array('form_id' => '15','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '0','has_website' => '0','has_address' => '1','has_message' => '0'),
	array('form_id' => '16','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '0','has_website' => '0','has_address' => '1','has_message' => '0'),
	array('form_id' => '17','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '0'),
	array('form_id' => '18','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '1','has_website' => '0','has_address' => '1','has_message' => '0'),
	array('form_id' => '19','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '0'),
	array('form_id' => '20','has_name' => '1','has_email' => '1','has_contact' => '1','has_dob' => '0','has_website' => '0','has_address' => '0','has_message' => '0')
	);


$table_name = $wpdb->prefix . "atf_form_structure"; 
foreach ($wp_atf_form_structure as $data) {
	$query = $wpdb->insert($table_name, $data);
}
}

	/**
	 * Fired for each blog when the plugin is deactivated.
	 *
	 * @since    1.0.0
	 */
	private static function single_deactivate() {
		// @TODO: Define deactivation functionality here
	}

	/**
	 * Load the plugin text domain for translation.
	 *
	 * @since    1.0.0
	 */
	public function load_plugin_textdomain() {

		$domain = $this->plugin_slug;
		$locale = apply_filters( 'plugin_locale', get_locale(), $domain );

		load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . $domain . '/' . $domain . '-' . $locale . '.mo' );
		load_plugin_textdomain( $domain, FALSE, basename( plugin_dir_path( dirname( __FILE__ ) ) ) . '/languages/' );

	}

	/**
	 * Register and enqueue public-facing style sheet.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_slug . '-plugin-styles', plugins_url( 'assets/css/public.css', __FILE__ ), array(), self::VERSION );
		wp_enqueue_style( $this->plugin_slug . '-zebra_datepicker-styles', plugins_url( 'assets/css/zebra_datepicker.css', __FILE__ ), array(), self::VERSION );
	}

	/**
	 * Register and enqueues public-facing JavaScript files.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_enqueue_script( $this->plugin_slug . '-serialize_JSON', plugins_url( 'assets/js/jquery_serializeJSON.js', __FILE__ ), array( 'jquery' ), self::VERSION );
		wp_enqueue_script( $this->plugin_slug . '-plugin-script', plugins_url( 'assets/js/public.js', __FILE__ ), array( 'jquery' ), self::VERSION );
		wp_enqueue_script( $this->plugin_slug . '-admin-script-modernizr', plugins_url( 'assets/js/modernizr.custom.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
		wp_enqueue_script( $this->plugin_slug . '-admin-script-classie', plugins_url( 'assets/js/classie.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
		wp_enqueue_script( $this->plugin_slug . '-zebra-datepicker-script', plugins_url( 'assets/js/zebra_datepicker.js', __FILE__ ), array( 'jquery' ), self::VERSION );
		wp_enqueue_script( $this->plugin_slug . '-admin-script-progressButton', plugins_url( 'assets/js/progressButton.js', __FILE__ ), array( 'jquery' ), Atf::VERSION );
	}

	/**
	 * NOTE:  Actions are points in the execution of a page or process
	 *        lifecycle that WordPress fires.
	 *
	 *        Actions:    http://codex.wordpress.org/Plugin_API#Actions
	 *        Reference:  http://codex.wordpress.org/Plugin_API/Action_Reference
	 *
	 * @since    1.0.0
	 */
	public function action_method_name() {
		// @TODO: Define your action hook callback here
	}


	// EMAIL SCHEDULER
	function set_scheduler($form_id, $recipient_list) {
		// $time = strtotime(date('Y-m-d H') . ':00:00');      
		// getting schedule through form id
		global $wpdb;
		$table_name = $wpdb->prefix . "atf_autoresponder_scheduler"; 
		$result = $wpdb->get_results("SELECT schedule_delay, autoresponder_name, autoresponder_body FROM $table_name where form_id = $form_id");
		print_r( $result );
		$day_time = 24*3600;

		foreach ($result as $delay) {
			$val = (int)$delay->schedule_delay;
			$scheduled_mail[] = array(
				'time' => $val * $day_time,
				'subject' => (string)$delay->autoresponder_name,
				'body' => $delay->autoresponder_body
				);
		}

		print_r($scheduled_mail);
		foreach ($scheduled_mail as $mail) {
			// wp_schedule_event( $time, 'daily', 'schedule_mail', $args);
			$time = time();
			$schedule = $time + $mail['time']; 
			echo $schedule. "\n" ;
			$to = $recipient_list;
			$subject = $mail['subject'];
			$body = $mail['body'];

			wp_schedule_single_event($schedule, 'schedule_mail', array($to, $subject, $body));
			// wp_schedule_single_event(time(), 'schedule_mail', array($to, $subject, $body));
		}

		// $args = array('recipient_list' => $recipient_list,
		// 	'schedule'=>
		// 	);        
		// wp_schedule_event( $time, 'daily', 'schedule_mail', $args);
	}

	public function action_schedule_mail($to, $subject, $body) {
		// @TODO: Define your action hook callback here
		echo $to . "\n" . $subject ."\n". $body;
		$headers = "MIME-Version: 1.0" . "\r\n";
		$headers .= "Content-type:text/html;charset=iso-8859-1" . "\r\n";
		// $headers .= "From: $blog_title <$admin_email>" . "\r\n";

		wp_mail( $to, $subject, $body, $headers );
	}

	// saving lead
	public function action_save_lead() {
		// @TODO: Define your action hook callback here
		global $wpdb;

		$str = $_POST['admin_data'];
		$str = (string)str_replace("\\","", $str);
		$data =json_decode($str, true);


		$name = "";
		$email = "";
		$contact = "";
		$message = "";
		$form_id = "";

		$dob = "";
		$website = "";
		$address = "";

		if(isset($data['Name']))
			$name = $data['Name'];

		if(isset($data['Email']))
			$email = $data['Email'];
		
		if(isset($data['Contact']))
			$contact = $data['Contact'];

		if(isset($data['Message']))
			$message = $data['Message'];

		if(isset($data['Website']))
			$website = $data['Website'];

		if(isset($data['DOB']))
			$dob = $data['DOB'];

		if(isset($data['Address']))
			$address = $data['Address'];

		if(isset($data['main_form_id']))
			$form_id = $data['main_form_id'];

		// status variable values: NULL, transfered
		$table_name = $wpdb->prefix . "atf_leads"; 
		$query = $wpdb->insert( $table_name, 
			array( 'name' => $name, 
				'email_address' => $email,
				'contact_number' => $contact, 
				'message' => $message,
				'dob' => $dob,
				'address' => $address,
				'website' => $website,
				'form_id' => $form_id   ) );

		$lastid = $wpdb->insert_id;
		echo $lastid;
	}

	public function atf_view_style() {
		// @TODO: Define your action hook callback here
		$id = $_POST['id'];

		?>
		<link rel="stylesheet" type="text/css" href="<?php echo plugins_url(); ?>/atf/admin/assets/css/admin.css">
		<link rel="stylesheet" type="text/css" href="<?php echo plugins_url(); ?>/atf/assets/default_stylesheets/default_form_<?php echo $id?>.css">
		<?php 
	}


	public function action_atf_view() {
		// @TODO: Define your action hook callback here
		global $wpdb;
		$id = $_POST['id'];

		$form_name = "";
		$header_bg_color = "";
		$header_text = "";
		$header_background_image = "";
		$body_desc = "";
		$body_redirect = "";
		$has_footer = "";
		$footer_heading = "";
		$footer_subheading = "";
		$footer_address = "";
		$footer_contact = "";
		$footer_email = "";


		// status variable values: NULL, transfered
		$table_name = $wpdb->prefix . "atf_customized_forms"; 
		$query = "SELECT * FROM ".$table_name." WHERE id = ".$id;


		$results = $wpdb->get_row($query);
		if($results != NULL){
			$form_name = $results->form_name;
			$header_bg_color = $results->header_bg_color;
			$header_text = $results->header_text;
			$header_background_image = $results->header_background_image;
			$body_desc = $results->body_desc;
			$body_redirect = $results->body_redirect;
			$has_footer = $results->has_footer;
			$footer_heading = $results->footer_heading;
			$footer_subheading = $results->footer_subheading;
			$footer_address = $results->footer_address;
			$footer_contact = $results->footer_contact;
			$footer_email = $results->footer_email;
		}

		$table_name = $wpdb->prefix . "atf_form_structure"; 
		$query = "SELECT * FROM ".$table_name." WHERE form_id = ".$id;

		$results = $wpdb->get_row($query);
		if($results != NULL){
			$has_name = $results->has_name;
			$has_email = $results->has_email;
			$has_contact = $results->has_contact;
			$has_dob = $results->has_dob;
			$has_website = $results->has_website;
			$has_address = $results->has_address;
			$has_message = $results->has_message;
		}

		// echo $table_name;



		if(($header_background_image!="")||($header_text!="")){
			echo "<div class=\"resultant-form-header\" style=\"min-height: 200px; text-align: center; background-color: $header_bg_color; ";
			if($header_background_image) echo "background: url('".$header_background_image."'); background-size: 100%; \">\n"; 
			else echo "\">\n";
			echo "						<span class=\"resultant-banner-header-text\" style=\"font-size: 24px; background: none; border: none; outline: none; padding: 10px 10px; color: #fff; line-height: 200px;  min-height: 200px; display:block; background-color: rgba(0,0,0,0.2); text-align: center;\">$header_text</span>\n"; 
			echo "					</div>\n"; 
		}
		echo "					<div class=\"resultant-form-body\" style=\"padding: 20px 20px; background: #fff; text-align: center; min-height: 100px;\">\n"; 
		echo "						<span class=\"resultant-form-desc\" style=\"font-size: 24px; font-family: 'lato', sans-serif; text-align: center; color: #888; padding: 5px;\">$body_desc</span>\n"; 
		echo "\n"; 
		echo "						<div class=\"row main-form\" style=\"padding: 15px 0px;\">\n"; 
		echo "							<form class=\"atf-form\" data-fid=\"$id\" action=\"action.php\" method=\"post\" onsubmit=\"return false;\">\n"; 
		echo "								<div class=\"row\">\n"; 
		echo "									<input type=\"hidden\" id=\"main_form_name\" value=\"$form_name\" name=\"main_form_name\" >\n"; 
		echo "									<input type=\"hidden\" id=\"main_form_id\" value=\"$id\" name=\"main_form_id\" >\n"; 

		if($has_name=="1")
			echo "									<input class=\"main-form-input\" placeholder=\"Name\" type=\"text\" id=\"main_form_name\" name=\"Name\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

		if($has_email=="1")
			echo "									<input class=\"main-form-input\" placeholder=\"Email\" type=\"email\" id=\"main_form_email\" name=\"Email\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

		if($has_contact=="1")
			echo "									<input class=\"main-form-input\" placeholder=\"Contact\" type=\"tel\" id=\"main_form_contact\" name=\"Contact\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

		if($has_dob=="1")
			echo "									<input class=\"main-form-input\" placeholder=\"dob\" type=\"text\" id=\"main_form_dob\" name=\"DOB\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

		if($has_website=="1")
			echo "									<input class=\"main-form-input\" placeholder=\"website\" type=\"text\" id=\"main_form_website\" name=\"Website\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\">\n"; 

		echo "									<input class=\"main-form-id\" type=\"hidden\" id=\"main_form_id\" value=\"$id\">\n"; 

		echo "\n"; 			

		if($has_address=="1")
			echo "									<textarea class=\"main-form-input\" placeholder=\"Address\" id=\"main_form_address\" name=\"Address\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\"></textarea>\n"; 

		if($has_message=="1")
			echo "									<textarea class=\"main-form-input\" placeholder=\"Message\" id=\"main_form_message\" name=\"Message\" style=\"outline: none !important; border: none; box-shadow: none; padding: 5px 10px ; font-size: 16px; margin-bottom: 15px; margin-top: 10px; display: block; width: 100%; border-bottom: 1px solid #eaeaea;\"></textarea>\n"; 
		echo "									<p class=\"perspective\">\n"; 
		echo "										<button type=\"submit\" id=\"main_form_submit\" class=\"main_form_submit btn btn-8 btn-8g\">\n"; 
		echo "											<i class=\"fa fa-envelope\"></i>SUBMIT\n"; 
		echo "										</button>\n"; 
		echo "									</p>\n"; 
		echo "								</div>\n"; 
		echo "							</form>\n"; 
		echo "						</div>\n"; 
		echo "					</div>\n"; 
		if($has_footer == "1"){
			echo "					<div class=\"resultant-form-footer\" style=\"padding: 20px 20px; background: #98D6D3; min-height: 100px; text-align: center;\">\n"; 
			echo "						<div class=\"resultant-footer-head\" style=\"font-size: 24px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 5px; margin-bottom: 10px; display: inline-block;\">$footer_heading</div>\n"; 
			echo "						<div class=\"resultant-footer-subhead\" style=\"font-size: 14px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 5px; padding-bottom: 20px; border-bottom: 1px solid #BEE6FF;\">$footer_subheading</div>\n"; 
			if($footer_address!=""){
				echo "						<div class=\"resultant-foo-address\" style=\"font-size: 14px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 10px; margin-bottom: 10px; display: block;\">\n"; 
				echo "							<i class=\"fa fa-map-marker\"></i>\n"; 
				echo "							<span class=\"resultant-address\">$footer_address</span>\n"; 
				echo "						</div>\n"; 
			}
			if($footer_contact!=""){
				echo "						<span class=\"resultant-foo-contact\" style=\"font-size: 14px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 10px; margin-bottom: 10px; display: inline-block;\">\n"; 
				echo "							<i class=\"fa fa-phone\"></i>\n"; 
				echo "							<span class=\"resultant-contact\">$footer_contact</span>\n"; 
				echo "						</span>\n"; 
			}
			if($footer_email!=""){
				echo "						<span class=\"resultant-foo-email\" style=\"font-size: 14px; font-family: 'lato', sans-serif; color: #3B6D8C; padding: 10px; margin-bottom: 10px; display: inline-block;\">\n"; 
				echo "							<i class=\"fa fa-envelope\"></i>\n"; 
				echo "							<span class=\"resultant-email\">$footer_email</span>\n"; 
				echo "						</span>\n"; 
				echo "					</div>\n"; 
			}
		}
		echo "				\n";
	}
	
	public function action_autoresponder() {
		global $wpdb;

		$admin_email = get_option( 'admin_email' ); 
		$blog_title = get_bloginfo('name');
		$author = get_the_author();
		$headers = "MIME-Version: 1.0" . "\r\n";
		$headers .= "Content-type:text/html;charset=iso-8859-1" . "\r\n";
		// $headers .= "From: $author <$admin_email>" . "\r\n";
		$message = "";
		$subject = "";
		$recipient_list = "";
		$recipient_list = $_POST['email'];
		$form_id = $_POST['form_id'];

		$subject = "Thank you for subscribing to $blog_title";

		$message = "";
		$table_name = $wpdb->prefix . "atf_form_autoresponder"; ;

		$message = $wpdb->get_var("SELECT form_autoresponder FROM $table_name WHERE form_id = $form_id");
		if($message !== ""){
			$message = stripslashes($message);
			wp_mail( $recipient_list, $subject, $message, $headers );
		}
		else{
			echo "No autoresponder set!";
		}
		

		// ---------------------------------------------------SENDING EMAIL TO ADMIN --------------------------------------
		// sending mail to the admin
		$admin_subject = "Subscriber Details from $blog_title";
		$headers = "MIME-Version: 1.0" . "\r\n";
		$headers .= "Content-type:text/html;charset=iso-8859-1" . "\r\n";
		$headers .= "From: $blog_title <$admin_email>" . "\r\n";


		$str = $_POST['admin_data'];

		$str = (string)str_replace("\\","", $str);
		$data =json_decode($str, true);

		// Retrieving last submitted lead id
		

		$admin_message = "<strong>Subscriber Details</strong><br><br>";
		$admin_message .= "<table style=\"width:500px\">";
		if(isset($data['Name']))
			$admin_message .= "<tr><td width=\"200px\"><strong>Name    </strong></td><td width=\"300px\">".$data['Name']."</td></tr>";
		if(isset($data['Email']))
			$admin_message = $admin_message."<tr><td><strong>Email    </strong></td><td>".$data['Email']."</td></tr><br>";
		if(isset($data['Contact']))
			$admin_message = $admin_message."<tr><td><strong>Contact    </strong></td><td>".$data['Contact']."</td></tr><br>";
		if(isset($data['DOB']))
			$admin_message = $admin_message."<tr><td><strong>DOB    </strong></td><td>".$data['DOB']."</td></tr><br>";
		if(isset($data['Website']))
			$admin_message = $admin_message."<tr><td><strong>Website    </strong></td><td>".$data['Website']."</td></tr><br>";
		if(isset($data['Address']))
			$admin_message = $admin_message."<tr><td><strong>Address    </strong></td><td>".$data['Address']."</td></tr><br>";
		if(isset($data['Message']))
			$admin_message = $admin_message."<tr><td><strong>Message    </strong></td><td>".$data['Message']."</td></tr><br>";
		$admin_message .= "</table>";

		$form_attr = "";
		if(isset($data['main_form_id']))
			$form_attr = $data['main_form_id'];

		if(isset($data['main_form_name'])&&($data['main_form_name']!=""))
			$form_attr = $data['main_form_name'];


		$table_name = $wpdb->prefix."atf_leads";
		$query = "SELECT max(id) FROM $table_name";

		$lead_id = $wpdb->get_var($query);
		$admin_subject = "ATF Lead: $form_attr - ".$data['Name']."(Lead #$lead_id) from $blog_title";

		echo $admin_message."   ".$admin_subject;
		
		wp_mail($admin_email, $admin_subject, $admin_message, $headers);

		// scheduling mails through set_scheduler
		if($recipient_list)
		$this->set_scheduler($form_id, $recipient_list);
	}


	// Updating form view counter
	public function update_view_ctr() {
		global $wpdb;
		$form_id = "";
		$table_name = $wpdb->prefix."atf_form_analytics";
		$form_id = $_POST['form_id'];
		
		$form_views = $wpdb->get_var("SELECT form_views FROM $table_name where form_id = '$form_id'");
		$form_views = $form_views + 1;
		$query = $wpdb->update( $table_name,
			array('form_views' => $form_views),
			array('form_id' => $form_id )
			);
	}

	// Updating form submission counter
	public function update_submission_ctr() {
		global $wpdb;
		$form_id = "";
		$table_name = $wpdb->prefix."atf_form_analytics";
		$form_id = $_POST['form_id'];
		
		$form_submissions = $wpdb->get_var("SELECT form_submissions FROM $table_name where form_id = '$form_id'");
		$form_submissions = $form_submissions + 1;
		$query = $wpdb->update( $table_name,
			array('form_submissions' => $form_submissions),
			array('form_id' => $form_id )
			);
	}
	/**
	 * Adds the WordPress Ajax Library to the frontend.
	 */
	public function add_ajax_library() {
		
		$html = '<script type="text/javascript">';
		$html .= 'var ajaxurl = "' . admin_url( 'admin-ajax.php' ) . '";';
		$html .= 'var plugins_url = "' . plugins_url() . '";';
		$html .= 'var pluginurl = "' . plugin_dir_url(basename( __DIR__ )) . '";';
		$html .= '</script>';
		
		echo $html;	
		
	} // end add_ajax_library


	/**
	 * NOTE:  Filters are points of execution in which WordPress modifies data
	 *        before saving it or sending it to the browser.
	 *
	 *        Filters: http://codex.wordpress.org/Plugin_API#Filters
	 *        Reference:  http://codex.wordpress.org/Plugin_API/Filter_Reference
	 *
	 * @since    1.0.0
	 */
	public function filter_method_name() {
		// @TODO: Define your filter hook callback here
	}

}
